BEGIN {
  use strict; use warnings;
  my %missing = map {
    eval qq{ require $_ };
    $@ ? ($_=>1) : ()
  } qw( experimental strict warnings );
  if(%missing)
  {
    print "Your Perl is missing core modules: @{[ sort keys %missing ]}\n";
    print "Ideally if you are using the system Perl you can install the appropriate\n";
    print "package which includes the core Perl modules.  On at least some versions\n";
    print "of Fedora, CentOS and RHEL, this is the `perl-core` package.\n";
    print "\n";
    print " % dnf install perl-core\n";
    print "   ~ or ~\n";
    print " % yum install perl-core\n";
    print "\n";
    print "If you really want to install dual-life modules from CPAN, then you can\n";
    print "use cpanm:\n";
    print "\n";
    print " % cpanm @{[ sort keys %missing ]}\n";
    print "\n";
    print "Note that some core modules are not available from CPAN.\n";
    exit;
  }
}
BEGIN {
  use strict; use warnings;
  unless(eval q{ use 5.020; 1}) {
    print "Perl 5.020 or better required\n";
    exit;
  }
}
# This file was automatically generated by Dist::Zilla::Plugin::Author::Plicease::MakeMaker v2.68.
use strict;
use warnings;
use 5.020;
use ExtUtils::MakeMaker;
use File::ShareDir::Install;

$File::ShareDir::Install::INCLUDE_DOTFILES = 1;
$File::ShareDir::Install::INCLUDE_DOTDIRS  = 1;
install_share module => "Dist::Zilla::MintingProfile::FFI", "profiles";

my %WriteMakefileArgs = (
  "ABSTRACT"           => "A minimal Dist::Zilla minting profile for FFI",
  "AUTHOR"             => "Graham Ollis <plicease\@cpan.org>",
  "CONFIGURE_REQUIRES" => {
    "ExtUtils::MakeMaker"     => 0,
    "File::ShareDir::Install" => "0.06"
  },
  "DISTNAME"         => "Dist-Zilla-MintingProfile-FFI",
  "LICENSE"          => "perl",
  "MIN_PERL_VERSION" => "5.020",
  "NAME"             => "Dist::Zilla::MintingProfile::FFI",
  "PM"               => {
    "lib/Dist/Zilla/MintingProfile/FFI.pm" => "\$(INST_LIB)/Dist/Zilla/MintingProfile/FFI.pm",
    "lib/Dist/Zilla/Plugin/FFI/Mint.pm"    => "\$(INST_LIB)/Dist/Zilla/Plugin/FFI/Mint.pm"
  },
  "PREREQ_PM" => {
    "Dist::Zilla::File::InMemory"                 => 0,
    "Dist::Zilla::Role::FileGatherer"             => 0,
    "Dist::Zilla::Role::FileMunger"               => 0,
    "Dist::Zilla::Role::MintingProfile::ShareDir" => 0,
    "Dist::Zilla::Role::ModuleMaker"              => 0,
    "Moose"                                       => 0,
    "namespace::autoclean"                        => 0
  },
  "TEST_REQUIRES" => {
    "Path::Tiny"                   => 0,
    "Test2::V0"                    => "0.000121",
    "Test::DZil"                   => 0,
    "Test::File::ShareDir::Module" => 0
  },
  "VERSION" => "0.01",
  "test"    => {
    "TESTS" => "t/*.t"
  }
);

my %FallbackPrereqs = (
  "Dist::Zilla::File::InMemory"                 => 0,
  "Dist::Zilla::Role::FileGatherer"             => 0,
  "Dist::Zilla::Role::FileMunger"               => 0,
  "Dist::Zilla::Role::MintingProfile::ShareDir" => 0,
  "Dist::Zilla::Role::ModuleMaker"              => 0,
  "Moose"                                       => 0,
  "Path::Tiny"                                  => 0,
  "Test2::V0"                                   => "0.000121",
  "Test::DZil"                                  => 0,
  "Test::File::ShareDir::Module"                => 0,
  "namespace::autoclean"                        => 0
);

unless ( eval { ExtUtils::MakeMaker->VERSION(6.63_03) } ) {
  delete $WriteMakefileArgs{TEST_REQUIRES};
  delete $WriteMakefileArgs{BUILD_REQUIRES};
  $WriteMakefileArgs{PREREQ_PM} = \%FallbackPrereqs;
}

delete $WriteMakefileArgs{CONFIGURE_REQUIRES}
  unless eval { ExtUtils::MakeMaker->VERSION(6.52) };

WriteMakefile(%WriteMakefileArgs);

{
  package
    MY;
  use File::ShareDir::Install qw(postamble);
}